@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Provide musical cadence chords
 
-our $VERSION = '0.0105';
+our $VERSION = '0.0200';
 
 use Music::Chord::Note;
 use Music::Scales;
@@ -19,15 +19,14 @@ sub cadence {
 
     my $cadence = [];
 
-    $args{key}     ||= 'C';
-    $args{scale}   ||= 'major';
-    $args{type}    ||= 'perfect';
-    $args{leading} ||= 1;
-    $args{octave}  //= 0;
+    $args{key}       ||= 'C';
+    $args{scale}     ||= 'major';
+    $args{type}      ||= 'perfect';
+    $args{octave}    //= 0;
+    $args{leading}   ||= 1;
+    $args{variation} ||= 1;
 
-    my $n     = 0;
     my @scale = get_scale_notes( $args{key}, $args{scale} );
-    my %notes = map { ++$n => $_ } @scale;
 
     my $mcn = Music::Chord::Note->new;
 
@@ -38,20 +37,21 @@ sub cadence {
     );
 
     if ( $args{type} eq 'perfect' ) {
-        $cadence = _generate_chord( $notes{5}, $args{octave}, $mtr, $mcn, $cadence );
-        $cadence = _generate_chord( $notes{1}, $args{octave}, $mtr, $mcn, $cadence );
+        $cadence = _generate_chord( $scale[4], $args{octave}, $mtr, $mcn, $cadence );
+        $cadence = _generate_chord( $scale[0], $args{octave}, $mtr, $mcn, $cadence );
     }
     elsif ( $args{type} eq 'plagal' ) {
-        $cadence = _generate_chord( $notes{4}, $args{octave}, $mtr, $mcn, $cadence );
-        $cadence = _generate_chord( $notes{1}, $args{octave}, $mtr, $mcn, $cadence );
+        $cadence = _generate_chord( $scale[3], $args{octave}, $mtr, $mcn, $cadence );
+        $cadence = _generate_chord( $scale[0], $args{octave}, $mtr, $mcn, $cadence );
     }
-    elsif ( $args{type} eq 'imperfect' ) {
-        $cadence = _generate_chord( $notes{ $args{leading} }, $args{octave}, $mtr, $mcn, $cadence );
-        $cadence = _generate_chord( $notes{5}, $args{octave}, $mtr, $mcn, $cadence );
+    elsif ( $args{type} eq 'half' ) {
+        $cadence = _generate_chord( $scale[ $args{leading} - 1 ], $args{octave}, $mtr, $mcn, $cadence );
+        $cadence = _generate_chord( $scale[4], $args{octave}, $mtr, $mcn, $cadence );
     }
     elsif ( $args{type} eq 'deceptive' ) {
-        $cadence = _generate_chord( $notes{5}, $args{octave}, $mtr, $mcn, $cadence );
-        $cadence = _generate_chord( $notes{6}, $args{octave}, $mtr, $mcn, $cadence );
+        $cadence = _generate_chord( $scale[4], $args{octave}, $mtr, $mcn, $cadence );
+        my $note = $args{variation} == 1 ? $scale[5] : $scale[3];
+        $cadence = _generate_chord( $note, $args{octave}, $mtr, $mcn, $cadence );
     }
 
     return $cadence;
@@ -87,7 +87,7 @@ Music::Cadence - Provide musical cadence chords
 
 =head1 VERSION
 
-version 0.0105
+version 0.0200
 
 =head1 SYNOPSIS
 
@@ -105,7 +105,7 @@ version 0.0105
   $notes = $mc->cadence(
     key     => 'C',
     scale   => 'major',
-    type    => 'imperfect',
+    type    => 'half',
     leading => 2,
     octave  => 0,
   ); # [['D','F','A'], ['G','B','D']]
@@ -134,22 +134,29 @@ Create a new C<Music::Cadence> object.
   $notes = $mc->cadence;  # Use defaults
 
   $notes = $mc->cadence(
-    key     => $key,      # Default: C
-    scale   => $scale,    # Default: major
-    type    => $type,     # Default: perfect
-    leading => $leading,  # Default: 1
-    octave  => $octave,   # Default: 0
+    key       => $key,        # Default: C
+    scale     => $scale,      # Default: major
+    type      => $type,       # Default: perfect
+    leading   => $leading,    # Default: 1
+    octave    => $octave,     # Default: 0
+    variation => $variation,  # Default: 1
   );
 
 Return an array reference of the chords of the cadence B<type> (and
-B<leading> chord when B<type> is C<imperfect>) based on the given B<key>
-and B<scale> name.  The B<octave> is optional and if given, should be
-a number greater than or equal to zero.
+B<leading> chord when B<type> is C<half>) based on the given B<key>
+and B<scale> name.
+
+The B<octave> is optional and if given, should be a number greater
+than or equal to zero.
+
+The B<variation> applies to the C<deceptive> cadence and determines
+the final chord.  If given as C<1>, the C<vi> chord is used.  If given
+as C<2>, the C<IV> chord is used.
 
 Supported cadences are:
 
   perfect
-  imperfect
+  half
   plagal
   deceptive
 
@@ -164,8 +171,8 @@ Supported scales are:
   locrian
 
 The B<leading> chord is a number for each diatonic scale chord to use
-for the first C<imperfect> cadence chord.  So for the key of
-C<C major> this is:
+for the first C<half> cadence chord.  So for the key of C<C major>
+this is:
 
   CM: 1
   Dm: 2
@@ -193,7 +200,7 @@ L<https://www.musictheoryacademy.com/how-to-read-sheet-music/cadences/>
 
 Evaded cadence
 
-Half cadences
+Imperfect cadence
 
 =head1 AUTHOR
 
